#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["url"]
import os
from os.path import *
from subprocess import *

dir = dirname(dirname(__file__))
if not dir: dir="."

file = join(dir,"url.txt")
if exists(file) and isfile(file): # ./url.txt
    url = open(file).read().lstrip().rstrip()
else:
    if exists(join(dir,".git")): # .git repo
        args = ["git","config","user.name"]
        process = Popen(args,stdout=PIPE)
        stdout,stderr = process.communicate()
        username = stdout.rstrip()

        name = basename(dir)
        url="https://github.com/%s/%s/" % (username,name)

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["author"]
try:
	from ConfigParser import * # python2
except:
	from configparser import * # python3
from os.path import *

# username
# https://docs.python.org/2/distutils/packageindex.html#pypirc
path = expanduser("~/.pypirc")
if exists(path):
    cfg = RawConfigParser()
    cfg.read(path)
    if cfg.has_option("pypi","username"):
        author = cfg.get('pypi', 'username')

if __name__=="__main__":
	for k in __all__:
		if k in globals():
			print("%s: %s" % (k,globals()[k]))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
__all__=["packages"]
import os
from os.path import *

dir = dirname(dirname(__file__))
if not dir: dir="."


file = join(dir,"packages.txt")
if exists(file):
    packages = open(file).read().lstrip().rstrip().splitlines()
else:
    # packages
    names = os.listdir(dir)
    names = list(filter(lambda _:_.lower()!="tests",names)) # exclude "tests"
    names = list(filter(lambda name:name.find(".")<0,names)) # exclude *.* names with dot
    fullpaths = list(map(lambda name:join(dir,name),names))
    dirs = list(filter(lambda path:isdir(path),fullpaths))
    packages = list(filter(lambda path:exists(join(path,"__init__.py")),dirs))
    packages = list(map(basename,packages))

if __name__=="__main__":
    for k in __all__:
        if k in globals():
            print("%s: %s" % (k,globals()[k]))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from os.path import *
from isbinary import *
from read import *
from public import *
from write import *

class Exception(Exception): pass

@public
def isshebang(l):
    """return True if line is shebang"""
    return l and l.find("#!")==0

@public
def shebang(path):
    """return file/string shebang"""
    if not path: return
    path = str(path)
    if not exists(path): return
    if isbinary(path): return
    content = read(path)
    lines = content.splitlines()
    if lines:
        l=lines[0] # first line
        if isshebang(l):
            l = l.replace("#!","",1)
            return l.lstrip().rstrip()

if __name__=="__main__":
    print(shebang(__file__)) # /usr/bin/env python
    print(shebang(None)) # None
    print(shebang("/bin/ls")) # None


